==> gretel-client-0.8.0rc5.tar.gz: gretel-client-0.8.0rc5/README.md <==
# Gretel Python Client

<p align="left">
<img width=15% src="https://gretel-public-website.s3.amazonaws.com/assets/gobs_the_cat_@1x.png" alt="Gobs the Gretel.ai cat" />
<i>CLI and Python SDKs for interacting with Gretel's privacy engineering APIs.</i>
</p>

![Run Test Suite](https://github.com/gretelai/gretel-python-client/workflows/Run%20Test%20Suite/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/gretel-client/badge/?version=stable)](https://gretel-client.readthedocs.io/en/stable/?badge=stable?badge=stable)
![GitHub](https://img.shields.io/github/license/gretelai/gretel-python-client)
[![PyPI](https://badge.fury.io/py/gretel-client.svg)](https://badge.fury.io/py/gretel-client)
[![Python](https://img.shields.io/pypi/pyversions/gretel-client.svg)](https://github.com/gretelai/gretel-python-client)
[![Downloads](https://pepy.tech/badge/gretel-client)](https://pepy.tech/project/gretel-client)
[![GitHub stars](https://img.shields.io/github/stars/gretelai/gretel-python-client?style=social)](https://github.com/gretelai/gretel-python-client)

## Getting Started

The following command will install the Gretel CLI and Python SDK

```
pip install git+https://github.com/gretelai/gretel-python-client@main
```

To configure the CLI, run

```
gretel configure
```

For more information please refer to our [CLI Getting Started Guide]().

## System Requirements

The Gretel CLI and python SDKs require Python version 3.7 or greater. Docker is required for local training and generation jobs.

For more information please refer to our [documentation]().

==> gretel-client-0.8.2.tar.gz: gretel-client-0.8.2/README.md <==
# Gretel Python Client

<p align="left">
<img width=15% src="https://gretel-public-website.s3.amazonaws.com/assets/gobs_the_cat_@1x.png" alt="Gobs the Gretel.ai cat" />
<i>CLI and Python SDKs for interacting with Gretel's privacy engineering APIs.</i>
</p>

![Run Test Suite](https://github.com/gretelai/gretel-python-client/workflows/Run%20Test%20Suite/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/gretel-client/badge/?version=stable)](https://gretel-client.readthedocs.io/en/stable/?badge=stable?badge=stable)
![GitHub](https://img.shields.io/github/license/gretelai/gretel-python-client)
[![PyPI](https://badge.fury.io/py/gretel-client.svg)](https://badge.fury.io/py/gretel-client)
[![Python](https://img.shields.io/pypi/pyversions/gretel-client.svg)](https://github.com/gretelai/gretel-python-client)
[![Downloads](https://pepy.tech/badge/gretel-client)](https://pepy.tech/project/gretel-client)
[![GitHub stars](https://img.shields.io/github/stars/gretelai/gretel-python-client?style=social)](https://github.com/gretelai/gretel-python-client)

## Getting Started

The following command will install the latest stable Gretel CLI and Python SDK


```
pip install gretel-client
```

To install the latest development version, you may run

```
pip install git+https://github.com/gretelai/gretel-python-client@main
```

To configure the CLI, run

```
gretel configure
```

## System Requirements

The Gretel CLI and python SDKs require Python version 3.7 or greater. Docker is required for local training and generation jobs.

For more information please refer to the [Gretel Environment Setup](https://docs.gretel.ai/environment-setup) docs.


## Client SDKs

The `gretel-client` package also ships with a set of Python Client SDKs that may be used to interact with Gretel APIs using a familiar pythonic interface. For more information on how to use these SDKs, please refer to the following links

* [Projects SDK Reference](https://python.docs.gretel.ai/en/latest/projects/index.html)
